@@ -22,6 +22,7 @@ class ACIProcessorQueueTupleABC:
         """
         raise NotImplementedError()
 
+    @property
     @abstractmethod
     def ckiUniqueKey(self):
         """ Chunked Index - Unique Key
@@ -34,6 +35,7 @@ class ACIProcessorQueueTupleABC:
         """
         raise NotImplementedError()
 
+    @classmethod
     @abstractmethod
-    def tupleType(self):
-        pass
+    def tupleType(cls):
+        raise NotImplementedError()
